Index: /issm/trunk-jpl/src/c/modules/SurfaceMassBalancex/Gembx.cpp
===================================================================
--- /issm/trunk-jpl/src/c/modules/SurfaceMassBalancex/Gembx.cpp	(revision 25418)
+++ /issm/trunk-jpl/src/c/modules/SurfaceMassBalancex/Gembx.cpp	(revision 25419)
@@ -407,5 +407,5 @@
 	//   0 : direct input from aValue parameter
 	//   1 : effective grain radius (Gardner & Sharp, 2009)
-	//   2 : effective grain radius (Brun et al., 2009)
+	//   2 : effective grain radius (Brun et al., 1992, Lefebre et al., 2003)
 	//   3 : density and cloud amount (Greuell & Konzelmann, 1994)
 	//   4 : exponential time decay & wetness (Bougamont & Bamber, 2005)
Index: /issm/trunk-jpl/src/m/classes/SMBgemb.m
===================================================================
--- /issm/trunk-jpl/src/m/classes/SMBgemb.m	(revision 25418)
+++ /issm/trunk-jpl/src/m/classes/SMBgemb.m	(revision 25419)
@@ -60,5 +60,5 @@
 			      % 0: direct input from aValue parameter
 			      % 1: effective grain radius [Gardner & Sharp, 2009]
 			      % 2: effective grain radius [Brun et al., 2009], with swIdx=1, SW penetration follows grain size in 3 spectral bands (Brun et al., 1992)
 			      % 3: density and cloud amount [Greuell & Konzelmann, 1994]
 			      % 4: exponential time decay & wetness [Bougamont & Bamber, 2005]
@@ -330,5 +330,5 @@
 					    '0: direct input from aValue parameter',...
 					    '1: effective grain radius [Gardner & Sharp, 2009]',...
-					    '2: effective grain radius [Brun et al., 2009], with swIdx=1, SW penetration follows grain size in 3 spectral bands (Brun et al., 1992)',...
+					    '2: effective grain radius [Brun et al., 1992; LeFebre et al., 2003], with swIdx=1, SW penetration follows grain size in 3 spectral bands (Brun et al., 1992)',...
 					    '3: density and cloud amount [Greuell & Konzelmann, 1994]',...
 					    '4: exponential time decay & wetness [Bougamont & Bamber, 2005]'})
@@ -60,5 +60,5 @@
 			      % 0: direct input from aValue parameter
 			      % 1: effective grain radius [Gardner & Sharp, 2009]
-			      % 2: effective grain radius [Brun et al., 2009], with swIdx=1, SW penetration follows grain size in 3 spectral bands (Brun et al., 1992)
+			      % 2: effective grain radius [Brun et al., 1992; LeFebre et al., 2003]], with swIdx=1, SW penetration follows grain size in 3 spectral bands (Brun et al., 1992)
 			      % 3: density and cloud amount [Greuell & Konzelmann, 1994]
 			      % 4: exponential time decay & wetness [Bougamont & Bamber, 2005]
Index: /issm/trunk-jpl/src/m/classes/SMBgemb.py
===================================================================
--- /issm/trunk-jpl/src/m/classes/SMBgemb.py	(revision 25418)
+++ /issm/trunk-jpl/src/m/classes/SMBgemb.py	(revision 25419)
@@ -66,5 +66,5 @@
             # 0: direct input from aValue parameter
             # 1: effective grain radius [Gardner & Sharp, 2009]
             # 2: effective grain radius [Brun et al., 2009], with swIdx=1, SW penetration follows grain size in 3 spectral bands (Brun et al., 1992)
             # 3: density and cloud amount [Greuell & Konzelmann, 1994]
             # 4: exponential time decay & wetness [Bougamont & Bamber, 2005]
@@ -175,5 +175,5 @@
                                                                  '0: direct input from aValue parameter',
                                                                  '1: effective grain radius [Gardner & Sharp, 2009]',
-                                                                 '2: effective grain radius [Brun et al., 2009], with swIdx=1, SW penetration follows grain size in 3 spectral bands (Brun et al., 1992)',
+                                                                 '2: effective grain radius [Brun et al., 1992; LeFebre et al., 2003], with swIdx=1, SW penetration follows grain size in 3 spectral bands (Brun et al., 1992)',
                                                                  '3: density and cloud amount [Greuell & Konzelmann, 1994]',
                                                                  '4: exponential time decay & wetness [Bougamont & Bamber, 2005]']))
@@ -66,5 +66,5 @@
             # 0: direct input from aValue parameter
             # 1: effective grain radius [Gardner & Sharp, 2009]
-            # 2: effective grain radius [Brun et al., 2009], with swIdx=1, SW penetration follows grain size in 3 spectral bands (Brun et al., 1992)
+            # 2: effective grain radius [Brun et al., 1992; LeFebre et al., 2003], with swIdx=1, SW penetration follows grain size in 3 spectral bands (Brun et al., 1992)
             # 3: density and cloud amount [Greuell & Konzelmann, 1994]
             # 4: exponential time decay & wetness [Bougamont & Bamber, 2005]
